@@ -5,13 +5,16 @@ from oscar.core.loading import get_class
 
 
 class PgSearchConfig(OscarConfig):
+    name = 'oscar_pg_search'
     label = 'search'
-    name = 'oscar.apps.search'
+    app_label = 'oscar_pg_search'
     verbose_name = _('Search')
 
     namespace = 'search'
 
     def ready(self):
+        super().ready()
+        #from . import models
         self.search_view = get_class('catalogue.views', 'CatalogueView')
 
     def get_urls(self):
